("GNU" "GNU")
("LaTeX" "LaTeX")
("TeX" "TeX")
("about" "om")
("above" "ver")
("abstract" "abstract")
("accent" "accent")
("activate" "aktivera")
("acute" "acute")
("address" "adress")
("advanced" "avancerad")
("after" "efter")
("all" "allt")
("alpha release" "alpha version")
("appendix" "appendix")
("apply" "tillmpa")
("april" "april")
("arab" "arabiskt")
("archaic" "archaiskt")
("architecture" "arkitektur")
("armenian" "armeniskt")
("arrow" "pil")
("article" "artikel")
("as on paper" "som p pappret")
("assign" "tilldela")
("attach" "bifoga")
("attach buffer to which project" "bifoga buffert till projekt")
("august" "augusti")
("author" "frfattare")
("automatic" "automatiskt")
("axiom" "axiom")
("background color" "bakgrundsfrg")
("bad data format" "felaktik dataformat")
("bar" "bar")
("bard" "bard")
("base level" "bas niv")
("bashkirian" "bashkirsiskt")
("basic" "basic")
("basic types" "grundlggande datatyper")
("be useful" "var nyttig")
("before" "fre")
("begin" "brja")
("below" "under")
("beta release" "beta version")
("bibliography" "bibliografi")
("bibliography file" "bibliografi fil")
("bibliography style" "bibliografi stil")
("big operator" "stor operator")
("big skip" "stort extraavstnd")
("binary operation" "bin operation")
("binary relation" "binr relation")
("black" "svart")
("blackboard bold" "svarta tavlan fet")
("blackboard math" "svarta tavlan matte")
("blackletter" "blackletter")
("blue" "bltt")
("body" "kropp")
("bold" "fet")
("book" "bok")
("bottom" "botten")
("bottom margin" "nedre kant")
("branch" "gren")
("break" "stopp")
("breve" "breve")
("brown" "brunt")
("buffer" "buffert")
("by" "av")
("by typing" "genom att skriva")
("bytes free" "bytes lediga")
("bytes used" "bytes anvnt")
("calligraphic" "kalligrafiskt")
("center" "centrum")
("centered" "centrerad")
("changes" "ndringar")
("chapter" "kapitel")
("check" "check")
("citation" "citat")
("class" "klass")
("clear" "rensa")
("clipped" "klippt")
("clipped and magnified" "klippt och frstorad")
("clipped and resized" "klippt och frndrad i storlek")
("clone" "klona")
("clone window" "klona fnster")
("close" "avsluta")
("close TeXmacs" "stng av TeXmacs")
("close buffer" "radera buffertt")
("close window" "stng fnster")
("color" "frg")
("column" "kolumn")
("column contains glued items" "kolumn innehller hoplistrade delar")
("compile buffer" "kompilera buffert")
("compile project" "kompilera projekt")
("concrete" "konkret")
("condensed" "ttt")
("copy" "kopiera")
("copying" "copyright")
("corollary" "corollar")
("cursors" "cursors")
("cut" "klipp ut")
("cypriot" "cypriotiskt")
("cyrillic" "kyrilliskt")
("cyrillic italic right" "kyrilliskt kursivt hger")
("dancers" "dansare")
("december" "december")
("default" "frinstllning")
("definition" "definition")
("delete" "radera")
("denominator" "nmnare")
("description" "beskrivning")
("detach" "avskilj")
("devangari" "devangari")
("disable indentation" "indrag av")
("disable indentation after" "indrag av efter")
("disable indentation before" "indrag av fre")
("document" "dokument")
("document style" "dokumentstil")
("document styles" "documentstil")
("dot" "punkt")
("double stroke" "dubbelstreckat")
("down" "ner")
("dpi" "dpi")
("dutch" "hollndska")
("edit" "redigera")
("empty box" "empty box")
("enable indentation" "indrag p")
("enable indentation after" "indrag p efter")
("enable indentation before" "indrag p fre")
("end" "sluta")
("english" "engelska")
("enumerate" "upprkna")
("enumerate|Alpha" "Alpha")
("enumerate|Roman" "Roman")
("enumerate|alpha" "alpha")
("enumerate|roman" "roman")
("env" "env")
("environment" "omgivning")
("epilogue" "epilog")
("equation" "ekvation")
("equations" "ekvationer")
("error" "fel")
("etruscan" "etruskiskt")
("evaluate scheme expression" "evaluate scheme expression")
("even page margin" "jmna sidors kant")
("exact horizontal" "exakt horisontellt")
("example" "exempel")
("execute" "utfr")
("execute a TeXmacs command" "utfr ett TeXmacs kommando")
("execute system command" "utfr systemkommando")
("executive" "executive")
("exercise" "vningsuppgift")
("export" "exportera")
("extend or normal" "utvigat eller normalt")
("family" "familj")
("february" "februari")
("figure" "figur")
("file" "fil")
("file name" "filnamn")
("file not found" "kan inte hitta filen")
("first indentation" "frsta indrag")
("first item" "frsta post")
("first page" "frsta sida")
("flat" "platt")
("font" "teckensnitt")
("font base size" "typsnitt basstorlek")
("font dpi" "typsnitt dpi")
("font family" "typsnittsfamilj")
("font series" "typsnittsserie")
("font shape" "typsnittsutseende")
("font size" "typsnitt storlek")
("foreign" "utndskt")
("formula" "formel")
("formula style" "formelstil")
("fraction" "fraction")
("french" "franska")
("function" "function")
("future changes" "planerade frndringar")
("general negation" "allmn negation")
("georgian" "georgiskt")
("german" "tyska")
("getting started" "komma igng")
("glossary" "glossar")
("glue" "glue")
("gothic" "gotiskt")
("graphical interface" "grafiskt grnssnitt")
("grave" "grave")
("greek" "grekiskt")
("greek letter" "grekisk bokstav")
("green" "grnt")
("grey" "grtt")
("group" "grupp")
("hat" "hat")
("hebrew" "hebriskt")
("height" "hjd")
("height magnification" "hjdfrstoring")
("help" "hjlp")
("help me" "hjlp mig")
("horizontal ink separation" "horisontell blck separation")
("horizontal position" "horisontell position")
("horizontal space" "horisontelt mellanslag")
("huge" "jttestort")
("hyperlink" "hyperlnk")
("hyphenation" "hyphenation")
("icelandic" "islndskt")
("image" "bild")
("implementation" "implementation")
("import" "importera")
("inactive" "inaktiv")
("indent" "indent")
("indentation flag" "indragsflagga")
("index" "index")
("index level" "index niv")
("insert" "foga in")
("insert Pr" "foga in Pr")
("insert a TeXmacs symbol" "foga in en TeXmacs symbol")
("insert a left subscript" "foga in vnster subscript")
("insert a new branch" "goga in ny gren")
("insert appendix" "foga in appendix")
("insert arccos" "foga in arccos")
("insert arcsin" "foga in arcsin")
("insert arctan" "foga in arctsn")
("insert arg" "foga in arg")
("insert argument" "foga in argument")
("insert big contour integral" "foga in stort kontur integraltecken")
("insert big coproduct" "foga in stort coprodukttecken")
("insert big direct sum" "foga in stort direkt summatecken")
("insert big dotted point" "foga in stor dotted point")
("insert big integral" "foga in stort integraltecken ")
("insert big intersection" "foga in stort snittecken")
("insert big logical and" "foga in logiskt och")
("insert big logical or" "foga in logiskt eller")
("insert big product" "foga in stort produkttecken")
("insert big square union" "foga in stort kantigt uniontecken")
("insert big summation" "foga in stort summatecken")
("insert big tensor product" "foga in stor tensorprodukt")
("insert big union" "foga in stort uniontecken")
("insert big union sum" "foga in stort union summatecken")
("insert big vertical space" "foga in tjock verticalt mellanslag")
("insert chapter" "foga in kapitel")
("insert cos" "foga in cos")
("insert cosh" "foga in cosh")
("insert cot" "foga in cot")
("insert coth" "foga in coth")
("insert csc" "foga in csc")
("insert deg" "foga in deg")
("insert det" "foga in det")
("insert dim" "foga in dim")
("insert dollar" "foga in dollar")
("insert equation" "foga in ekvation")
("insert exp" "foga in exp")
("insert formula" "foga in formel")
("insert gcd" "foga in gcd")
("insert hom" "foga in hom")
("insert horizontal interword space" "foga in horisontellt interword mellanslag")
("insert inf" "foga in inf")
("insert ker" "foga in ker")
("insert lg" "foga in lg")
("insert lim" "foga in")
("insert liminf" "foga in liminf")
("insert limsup" "foga in limsup")
("insert ln" "foga in ln")
("insert log" "foga in log")
("insert max" "foga in max")
("insert medium horizontal space" "foga in mellanstort horisontellt mellanslag")
("insert medium vertical space" "foga in mellanstort vertikalt mellanslag")
("insert min" "foga in min")
("insert negative horizontal space" "foga in negativt horisontellt mellanslag")
("insert new item or number" "foga in ny post eller nummer")
("insert sec" "foga in sec")
("insert section" "foga in avsnitt")
("insert sharp" "foga in sharp")
("insert sin" "foga in sin")
("insert sinh" "foga in sinh")
("insert small horizontal space" "foga in letet horisontellt mellanslag")
("insert small vertical space" "foga in litet vertikalt mellanslag")
("insert subsection" "foga in underavsnitt")
("insert subsubsection" "foga in underunderavsnitt")
("insert sup" "foga in sup")
("insert tan" "foga in tan")
("insert tanh" "foga in tanh")
("insert thick horizontal space" "foga in tjockt horisontellt mellanslag")
("interline space" "radavstnd")
("interparagraph space" "avstnd mellan avsnitt")
("introduction" "introduction")
("invisible citation" "osynlig citat")
("irish" "irlndskt")
("italic" "kursivt")
("italic right" "kursivt hger")
("itemize" "specificera")
("january" "januari")
("july" "juli")
("june" "juni")
("justified" "utjmnad")
("keyboard" "tangentbord")
("keymaps" "tangenter")
("kill" "dda")
("known bugs" "bekanta fel")
("label" "etikett")
("landscape" "landskap")
("language" "sprk")
("large" "stort")
("large closing bracket" "large closing bracket")
("large delimiter" "large delimiter")
("large opening bracket" "large opening bracket")
("large separator" "large seperator")
("last indentation" "sista indrag")
("last page" "sista sida")
("latex command" "latex kommando")
("latin" "latin")
("layout" "uppsttning")
("left" "vnster")
("left border" "vnstra begrnsning")
("left margin" "vnster kant")
("left aligned" "vnsterjusterad")
("left slanted" "lutat t vnster")
("left subscript" "subscript vnster")
("left superscript" "superscript vnster")
("legal" "legal")
("lemma" "lemma")
("letter" "letter")
("license" "licens")
("light" "smalt")
("limitations" "begrnsningar")
("line" "linje")
("line break" "stoppa rad")
("line stretch" "radtjning")
("link" "lnk")
("list" "lista")
("list of figures" "figurlista")
("list of tables" "tabelllista")
("load" "ppna")
("load LaTeX file" "ppna LaTeX fil")
("load TeX file" "ppna TeX fil")
("load TeXmacs file" "ladda TeXmacs fil")
("load TeXmacs style file" "ladda TeXmacs stylefil")
("load html file" "ladda html fil")
("load in new window" "ppna i nytt fnster")
("load latex file" "ladda latex fil")
("load more recent autosave file" "ladda nyare autosave fil")
("load tex file" "ladda tex fil")
("load verbatim file" "ladda verbatim fil")
("loaded" "laddat")
("long" "lng")
("lower border" "nedra begrnsning")
("magenta" "magenta")
("magic" "magiskt")
("magnification" "frstoring")
("magnified" "frstorad")
("make acute" "skapa acute")
("make bar" "skapa bar")
("make check" "skapa check")
("make fraction" "skapa fraction")
("make grave" "skapa grave")
("make hat" "skapa hat")
("make label" "skapa etikett")
("make negation" "skapa negation")
("make reference" "skapa referens")
("make square root" "skapa kvadratrot")
("make tilde" "skapa tilde")
("make title" "skapa titel")
("make vector" "skapa vector")
("march" "mars")
("margins" "kanter")
("math" "matte")
("math font" "math typsnitt")
("math font family" "math typsnittsfamilj")
("math font series" "math typsnittsserie")
("math font shape" "math typsnittsutseende")
("mathematical" "matematiskt")
("mathematics" "matematik")
("matrix" "matris")
("may" "maj")
("medium" "mellan")
("medium skip" "mellan extraavstnd")
("meminfo" "meminfo")
("messy" "rrigt")
("middle" "middle")
("minus" "minus")
("miscellaneous" "blandat")
("mode" "modus")
("mongolian" "mongoliskt")
("mosaic" "mosaic")
("move down" "flytta ner")
("move object" "flytta objekt")
("move to the right when finished" "flytta t hger nr klart")
("move up" "flytta upp")
("n-th" "n-th")
("n-th root" "n-rot")
("name" "namn")
("negation" "negation")
("new" "ny")
("new column" "ny kolumn")
("new item" "ny post")
("new line" "ny rad")
("new number" "nytt nummer")
("new page" "ny sida")
("new paragraph" "nytt stycke")
("new roman" "new roman")
("new row" "ny rad")
("new table" "ny tabell")
("next line" "nsta rad")
("no changes need to be saved" "inge frndringar behver sparas")
("no first indentation" "inget frsta indrag")
("no last indentation" "inget sista indrag")
("no line break" "inget radstopp")
("no name" "inget namn")
("no page break after" "ingen sidostopp efter")
("no page break before" "ingen sidostopp fre")
("none" "ingen")
("normal" "normalt")
("not found" "inte hittat")
("note" "notis")
("november" "november")
("numbered equation" "numererad ekvation")
("numbered equations" "numererade ekvationer")
("numerator" "tljare")
("numeric" "numersikt")
("objectives" "ml")
("october" "oktober")
("odd page margin" "udda sidors kant")
("off" "av")
("old english" "gammaldags engelskt")
("old slavonic" "gammaldags slaviskt")
("on" "p")
("open new window" "ppna nytt fnster")
("optical" "optiskt")
("option" "option")
("options" "optioner")
("orange" "orange")
("orientation" "orientering")
("other" "annat")
("other projects" "andra projekt")
("outlined roman" "outlined roman")
("page" "sida")
("page bottom margin" "sidans nedre kant")
("page break" "stoppa sida")
("page height" "sidhjd")
("page layout" "siduppsttning")
("page right margin" "sidans hgra kan")
("page top margin" "sidans vre kant")
("page type" "sidtyp")
("page width" "sidbredd")
("paper" "papper")
("paper type" "pappersstorlek")
("papyrus" "papyrus")
("paragraph" "paragraf")
("paragraph mode" "paragraf modus")
("paragraph width" "paragrafbredd")
("part" "del")
("past changes" "frndringar sedan frra versionen")
("paste" "klistra in")
("path" "skvg")
("phantasy" "fantasi")
("phoenician" "phniciskt")
("phonetic" "fonetiskt")
("pink" "rosa")
("please" "snlla")
("portrait" "portrtt")
("position" "position")
("postscript" "postscript")
("postscript image" "postscript bild")
("pre-alpha release" "pre-alpha version")
("preamble" "prambel")
("preview before printing" "visa fre utskrift")
("preview with ghostview" "visa mha ghostscript")
("print" "skriv ut")
("print all" "skriv ut allt")
("print all to file" "print all to file")
("print page selection" "skriv ut urval")
("print page selection to file" "print page selection to file")
("print to postscript file" "spara som postscript fil")
("printer dpi" "skrivarens upplsning")
("printing command" "utskriftskommando")
("professional" "professionellt")
("prog" "prog")
("prog font" "prog typsnitt")
("prog font family" "prog typsnittsfamilj")
("prog font series" "prog typsnittsserie")
("prog font shape" "prog typsnittsutseende")
("program" "programm")
("program mode" "programmod")
("project" "projekt")
("projects" "projekt")
("prologue" "prolog")
("proof" "bevis")
("proportional typewriter" "proportionell skrivmaskin")
("proposition" "proposition")
("quit" "avsluta")
("quotation" "quotation")
("quote" "citat")
("really huge" "gigantiskt")
("really quit" "verkligen avsluta")
("red" "rtt")
("reduce bottom margin by" "frminska nedra kant med")
("reduce left margin by" "frminska vnstra kant med")
("reduce margins" "frminska kanter")
("reduce right margin by" "frminska hgra kant med")
("reduce top margin by" "frminska vra kant med")
("reduction even page margin" "minska jmna sidors kant")
("reduction odd page margin" "minska udda sidor kant")
("reduction page bottom margin" "minska sidans nedre kant")
("reduction page right margin" "minska sidans hgra kant")
("reduction page top margin" "minska sidans vre kant")
("reference" "referens")
("references" "referenser")
("release" "version")
("remark" "kommentar")
("reset" "reset")
("resize object" "ndra objektets storlek")
("resized" "frndrad storlek")
("return" "return")
("revert buffer" "revert buffer")
("right" "hger")
("right border" "hgra begrnsning")
("right margin" "hger kant")
("right aligned" "hgerjusterad")
("right subscript" "subscript hger")
("right superscript" "superscript hger")
("rigid" "stel")
("rigid horizontal" "stelt horizontal")
("rigid space" "stelt mellanslag")
("romanian" "rumnska")
("root" "rot")
("row" "rad")
("row contains glued items" "rad innehller hoplistrade delar")
("runic" "runsten")
("sans serif" "sans serif")
("save" "spara")
("save TeXmacs file" "spara TeXmacs fil")
("save TeXmacs style file" "spara TeXmacs style fil")
("save as" "spara som")
("save as LaTeX" "spara som LaTeX")
("save as TeX" "spara som TeX")
("save html file" "spara html fil")
("save latex file" "spara latex fil")
("save tex file" "spara tex fil")
("save verbatim file" "spara verbatim fil")
("saved" "sparat")
("screen layout" "bildskrmslayout")
("screen margins" "skrmkanter")
("script" "script")
("script above" "script ver")
("script below" "script under")
("script script size" "skript skript storlek")
("script size" "skript storlek")
("section" "avsnitt")
("selected region" "utvald region")
("selection" "utval")
("seminar" "seminar")
("separation between lines" "radavstnd")
("separation between paragraphs" "avstnd mellan avsnitt")
("separator" "separator")
("september" "september")
("series" "serie")
("series|right" "hger")
("session" "session")
("set" "stll in")
("set margins" "stll in kanter")
("set n" "stll in n")
("set printer dpi" "stll in skrivarens dpiupplsning")
("set printing command" "stll in utskriftskommando")
("set text width" "stll in textbredd")
("setup printer" "skrivarinstllningar")
("shape" "form")
("shift-down" "shift-ner")
("shift-right" "shift-hger")
("show header and footer" "visa header och footer")
("shrinking factor" "frminskningsfaktor")
("size" "storlek")
("slanted" "snett")
("small" "lite")
("small caps" "sm bokstver")
("small skip" "litet extraavstnd")
("space" "mellanslag")
("spacing" "avstnd")
("special" "special")
("specific" "specifikt")
("split" "dela")
("square root" "kvadratrot")
("start" "brja")
("stretchable" "tjbart")
("stretchable horizontal" "tjbart horisontellt")
("stretchable vertical" "tjbart vertikalt")
("style" "stil")
("styles" "stil")
("subscript" "subscript")
("subsection" "underavsnitt")
("subsubsection" "underunderavsnitt")
("superscript" "superscript")
("swedish" "svenska")
("switch to formula style" "byt till formelstil")
("symbol" "symbol")
("tab" "tabulator")
("table" "tabell")
("table of contents" "innehllsfrteckning")
("tabular" "tabulera")
("test" "testa")
("tex" "tex")
("text" "text")
("text font" "text typsnitt")
("text width" "textbredd")
("th century bc" "th century bc")
("th root" "th rot")
("thai" "thailndskt")
("theorem" "teorem")
("there are unsaved files" "det finns icke-sparade filer")
("this line" "denna rad")
("tilda" "tilda")
("tilde" "tilde")
("tiny" "pyttelite")
("title" "titel")
("top" "topp")
("top level" "top niv")
("top margin" "vre kant")
("tree" "trd")
("turkish" "turkiskt")
("type" "typ")
("type a latex command followed by" "sl in latex kommando som fljs av")
("type body" "sl in kropp")
("type denominator" "sl in nmnaren")
("type numerator" "sl in tljaren")
("type script" "sl in skript")
("typewriter" "skrivmaskin")
("typewriter small caps" "skrivmaskin sm bokstver")
("ugaritic" "ugaritiskt")
("undo" "ngra")
("up" "upp")
("update" "uppdatera")
("upper border" "vra begrnsning")
("use a black color" "anvnd svart frg")
("use a blue color" "anvnd bl frg")
("use a brown color" "anvnd brun frg")
("use a green color" "anvnd grn frg")
("use a grey color" "anvnd gr frg")
("use a magenta color" "anvnd magenta frg")
("use a orange color" "anvnd orange frg")
("use a pink color" "anvnd rosa frg")
("use a red color" "anvnd rd frg")
("use a white color" "anvnd vit frg")
("use a yellow color" "anvnd gul frg")
("use blackboard bold font" "anvnd blackboard typsnitt")
("use bold font series" "anvnd fet typsnittsserie")
("use calligraphic font" "anvnd kalligrafiskt typsnitt")
("use footnote font size" "anvnd fotnot fontstorlek")
("use fraktur font" "anvnd fraktur typsnitt")
("use huge font size" "anvnd gigantisk fontstorlek")
("use italic font shape" "anvnd kursivt typsnittsutseende")
("use large font size" "anvnd stor fontstorle")
("use medium font series" "anvnd medium typsnittsserie")
("use normal font size" "anvnd normal fontstorlek")
("use package" "anvnd paket")
("use really huge font size" "anvnd jttegigantiskt storlek")
("use right font shape" "anvnd rtt typsnittsutseende")
("use roman font family" "anvnd roman typsnittsfamilj")
("use sans serif font family" "anvnd serif typsnittsfamilj")
("use script font size" "anvnd skript fontstorlek")
("use slanted font shape" "anvnd snett typsnittsutseende")
("use small font size" "anvnd liten fontstorlek")
("use small-caps font shape" "anvnd small-caps typsnittsutseende")
("use tiny font font size" "anvnd pyttefontstorlek")
("use typewriter font family" "anvnd skrivmaskin typsnittsfamilj")
("use very large font size" "anvnd jttestor fonstorlek")
("vector" "vector")
("verbatim" "ordagrant")
("verse" "vers")
("vertical after" "vertikalt efter")
("vertical before" "vertikalt fre")
("vertical position" "vertical position")
("vertical space" "vertikalt mellanslag")
("very large" "mycket stort")
("very small" "mycket lite")
("vietnamese" "vietnamesiskt")
("warning" "varning")
("welcome" "vlkommen")
("welcome to TeXmacs" "vlkommen till TeXmacs")
("when finished" "nr klart")
("white" "vitt")
("wide accent" "wide accent")
("width" "bredd")
("width magnification" "breddfrstoring")
("window height" "fnsterhjd")
("window width" "fnsterbredd")
("yellow" "gult")
("you can also obtain" "du kan ocks f")
